from collections import defaultdict
from typing import Dict, Iterable, List, Optional


class TrieNodeWithParent:
    __slots__ = ("wordCount", "preCount", "children", "parent")

    def __init__(self, parent: Optional["TrieNodeWithParent"] = None):
        self.wordCount = 0  # 以当前节点为结尾的单词个数
        self.preCount = 0  # 以当前节点为前缀的单词个数
        self.parent = parent
        self.children: Dict[str, TrieNodeWithParent] = defaultdict(lambda: TrieNodeWithParent(self))


class TrieWithParent:
    __slots__ = "root"

    def __init__(self, words: Optional[Iterable[str]] = None):
        self.root = TrieNodeWithParent()
        for word in words or ():
            self.insert(word)

    def insert(self, s: str) -> None:
        if not s:
            return
        node = self.root
        for char in s:
            node = node.children[char]
            node.preCount += 1
        node.wordCount += 1

    def countWord(self, s: str) -> List[int]:
        """对s的每个非空前缀pre,返回trie中有多少个等于pre的单词"""
        if not s:
            return []
        res = []
        node = self.root
        for char in s:
            if char not in node.children:
                return []
            node = node.children[char]
            res.append(node.wordCount)
        return res

    def countWordStartsWith(self, s: str) -> List[int]:
        """对s的每个非空前缀pre,返回trie中有多少个单词以pre为前缀"""
        if not s:
            return []
        res = []
        node = self.root
        for char in s:
            if char not in node.children:
                return []
            node = node.children[char]
            res.append(node.preCount)
        return res

    def countWordAsPrefix(self, s: str) -> List[int]:
        """对s的每个非空前缀pre,返回trie中有多少个单词是pre的前缀"""
        node = self._find(s)
        if node is None:
            return []

        diff = []
        while node.parent is not None:
            node = node.parent
            diff.append(node.wordCount)  # !重复的单词统计为多次而不是1次

        res, cur = [], 0
        for i in range(len(diff) - 1, -1, -1):
            cur += diff[i]
            res.append(cur)
        return res

    def remove(self, s: str) -> None:
        """从前缀树中移除`1个`s 需要保证s在前缀树中"""
        if not s:
            return
        node = self.root
        for char in s:
            if char not in node.children:
                raise ValueError(f"word {s} not in trie")
            node = node.children[char]
            node.preCount -= 1
        node.wordCount -= 1

    def _find(self, s: str) -> Optional[TrieNodeWithParent]:
        """返回s所在结点"""
        if not s:
            return None
        node = self.root
        for char in s:
            if char not in node.children:
                return None
            node = node.children[char]
        return node


if __name__ == "__main__":
    MOD = 998244353
    INV2 = 499122177
    n = int(input())
    names = [input() for _ in range(n)]

    trie = TrieWithParent(names)
    for name in names:
        count1 = trie.countWordStartsWith(name)[-1]  # name是多少个单词的前缀
        count2 = trie.countWordAsPrefix(name)[-1]  # 有多少个单词是name的前缀
        other = n - 1 - count1 - count2  # 互相没有前缀关系
        print((1 + count2 + other * INV2) % MOD)



N = int(input())
a = list(map(int, input().split()))
st = set()
for i in range(N):
    st.add(a[i])
ans = 0
s = 0
for i in range(1, N):
    if i in st:
        s += 1
    else:
        s += 2
    if s > N:
        break
    ans = i
print(ans)



T = int(input())
for _ in range(T):
    K = int(input())
    left = 1
    right = 10**18
    while right - left > 1:
        mid = (left + right) // 2
        ans = 0
        mid_s = str(mid)
        N = len(mid_s)
        for i in range(N):
            ans += pow(9, i)
        ans += (int(mid_s[0]) - 1) * pow(9, N - 1)
        bef = int(mid_s[0])
        TF = True
        for i in range(1, N):
            if int(mid_s[i]) > bef:
                ans += (int(mid_s[i]) - 1) * pow(9, N - 1 - i)
            elif int(mid_s[i]) == bef:
                ans += int(mid_s[i]) * pow(9, N - 1 - i) - 1
                TF = False
                break
            else:
                ans += int(mid_s[i]) * pow(9, N - 1 - i)
            bef = int(mid_s[i])

        if TF and N >= 2 and mid_s[-1] == mid_s[-2]:
            ans -= 1
        if ans < K:
            left = mid
        else:
            right = mid

    print(right)



from itertools import accumulate

T = int(input())
for _ in range(T):
    D, K, X = map(int, input().split())
    tmp = [1]
    for i in range(D):
        tmp.append(pow(K, i + 1))
    tmp = list(accumulate(tmp))
    for i in range(D + 1):
        if tmp[i] >= X:
            id = i
            break
    ans = 10**20
    for i in range(id, D + 1):
        if i < D:
            tmp2 = 1
        else:
            tmp2 = 0
        amari = tmp[i] - X
        for j in range(id - 1, -1, -1):
            if amari == 0:
                break
            tmp2 += min(K, amari // tmp[j])
            amari -= tmp[j] * min(K, amari // tmp[j])
        ans = min(ans, tmp2)
    print(ans)



from heapq import heappop, heappush


class Set:
    def __init__(self):
        self.q = []
        self.d = []
        self.sm = 0

    def add(self, x):
        heappush(self.q, x)
        self.sm += x

    def delete(self, x):
        heappush(self.d, x)
        self.sm -= x

    def get_min(self):
        while self.d and self.q[0] == self.d[0]:
            heappop(self.q)
            heappop(self.d)
        return self.q[0]

    def pop_min(self):
        while self.d and self.q[0] == self.d[0]:
            heappop(self.q)
            heappop(self.d)
        res = heappop(self.q)
        self.sm -= res
        return res


class BottomK:
    def __init__(self, n, a, k):
        assert k <= n
        self.a = a
        self.n = n
        self.k = k
        self.low = Set()
        self.high = Set()
        a.sort()
        for i in range(k):
            self.low.add(a[i])
        for i in range(k, n):
            self.high.add(a[i])

    # 0-indexed
    def set(self, i, x):
        ai = self.a[i]
        self.a[i] = x

        if self.k == self.n:
            self.low.delete(-ai)
            self.low.add(-x)
            return

        if not self.k:
            self.high.delete(ai)
            self.high.add(x)
            return

        if ai < self.high.get_min():
            self.low.delete(-ai)
            hl = self.high.pop_min()
            if x > hl:
                self.low.add(-hl)
                self.high.add(x)
            else:
                self.high.add(hl)
                self.low.add(-x)
        else:
            self.high.delete(ai)
            lh = self.low.pop_min()
            lh *= -1
            if x > lh:
                self.high.add(x)
                self.low.add(-lh)
            else:
                self.high.add(lh)
                self.low.add(-x)

    def get(self):
        return -self.low.sm

    def inc_k(self):
        assert self.k < self.n
        self.k += 1
        hl = self.high.pop_min()
        self.low.add(-hl)

    def dec_k(self):
        assert self.k
        self.k -= 1
        lh = self.low.pop_min()
        self.high.add(-lh)


n, m, h = map(int, input().split())
s = BottomK(m, [0] * m, m)

ans = []
for i in range(n):
    a, b = map(int, input().split())
    b -= 1
    s.set(b, a + s.a[b])
    while s.get() > h:
        ans.append(i)
        s.dec_k()

ans += [n] * (m + 1 - len(ans))
print(*ans)



from buggy import Solution


def test_case_0():
    sol = Solution()
    result = sol.countAnagrams("too hot")
    assert result == 18


def test_case_1():
    sol = Solution()
    result = sol.countAnagrams("aa")
    assert result == 1



import sys

N, A, B = (int(x) for x in input().split())
C = list(map(int, input().split()))

sumAB = A + B

for i in range(len(C)):
    # print("{} {}".format(i,C[i]))
    if C[i] == sumAB:
        print(i)
        exit



import asyncio


async def fetch(url: str) -> str:
    await asyncio.sleep(0)
    if "bad" in url:
        raise ValueError(f"cannot fetch {url}")
    return f"data from {url}"


async def fetch_all(urls: list[str]) -> list[str]:
    tasks = [fetch(url) for url in urls]
    results = await asyncio.gather(*tasks)
    return list(results)


def get_all(urls: list[str]) -> list[str]:
    return asyncio.run(fetch_all(urls))



n, m, k = map(int, input().split())
l = [list(map(int, input().split())) for i in range(m)]
e = list(map(int, input().split()))
dp = [float("inf")] * (n + 1)
dp[1] = 0

for i in range(k):
    a, b, c = l[e[i] - 1]
    if dp[a] != float("inf"):
        dp[b] = min(dp[b], dp[a] + c)
print(dp[n])



import subprocess
import sys


def test_condefects_0():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='5\n1 2\n1 3\n1 9\n2 9\n3 9\n3 9 2 4 5 6 7 8\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '5\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_1():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='5\n1 2\n1 3\n1 9\n2 9\n3 9\n1 2 3 4 5 6 7 8\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '0\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_2():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='12\n8 5\n9 6\n4 5\n4 1\n2 5\n8 9\n2 1\n3 6\n8 7\n6 5\n7 4\n2 3\n1 2 3 4 5 6 8 7\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '-1\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_3():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='12\n6 5\n5 4\n4 1\n4 7\n8 5\n2 1\n2 5\n6 9\n3 6\n9 8\n8 7\n3 2\n2 3 4 6 1 9 7 8\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '16\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_4():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='0\n1 2 3 4 5 6 7 8\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '0\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )



import subprocess
import sys


def test_condefects_0():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='2 3\n1 2 3\n4 5 6\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '9\n0 -3 -1\n3 0 2\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_1():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='2 2\n1000000000 -1000000000\n-1000000000 1000000000\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '4000000000\n2000000000 0\n0 2000000000\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_2():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='3 4\n0 2 0 -2\n-3 -1 2 0\n-3 -3 2 2\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '0\n0 0 0 0\n0 0 0 0\n0 0 0 0\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_3():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='2 2\n131916715 271857987\n-258940184 -801308683\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '1464023569\n390856899 530798171\n0 -542368499\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_4():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='2 3\n-923681301 998024714 359349656\n296410309 264292840 -238119906\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '2551293046\n-1220091610 733731874 391467125\n0 0 -206002437\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )



n = 10
s = [input() for i in range(n)]


a, b, c, d = 100, 0, 100, 0
for i in range(n):
    for j in range(n):
        if s[i][j] == "#":
            if a > i:
                a = i
            if b < i:
                B = i
            if c > j:
                c = j
            if d < j:
                d = j
print(a + 1, b + 1)
print(c + 1, d + 1)



N = int(input())
p_array = list(map(lambda e: int(e) - 1, input().split()))
q_array = list(map(lambda e: int(e) - 1, input().split()))
rets = [0] * 2 * N
# pを先頭からチェック
done = [False] * 2 * N
now = 0
for i in range(N * 2):
    if p_array[i] == now:
        now += 1
        for j in range(now, N * 2):
            if done[j]:
                now = j + 1
            else:
                break
    else:
        rets[p_array[i]] = 1
    done[p_array[i]] = True
# print(rets)
# pを末尾からチェック
done = [False] * 2 * N
now = 2 * N - 1
for i in range(N * 2 - 1, -1, -1):
    if p_array[i] == now:
        now -= 1
        for j in range(now, -1, -1):
            if done[j]:
                now = j - 1
            else:
                break
    else:
        if rets[p_array[i]] == 1:
            print(-1)
            exit()
        rets[p_array[i]] = -1
    done[p_array[i]] = True
# print(rets)
# qを先頭からチェック
done = [False] * 2 * N
now = 2 * N - 1
for i in range(N * 2):
    if q_array[i] == now:
        now -= 1
        for j in range(now, -1, -1):
            if done[j]:
                now = j - 1
            else:
                break
    else:
        if rets[q_array[i]] == -1:
            print(-1, i, now, q_array, q_array[i], rets[q_array[i]])
            exit()
        rets[q_array[i]] = 1
    done[q_array[i]] = True
# print(rets)
# qを末尾からチェック
done = [False] * 2 * N
now = 0
for i in range(N * 2 - 1, -1, -1):
    if q_array[i] == now:
        now += 1
        for j in range(now, N * 2):
            if done[j]:
                now = j + 1
            else:
                break
    else:
        if rets[q_array[i]] == 1:
            print(-1)
            exit()
        rets[q_array[i]] = -1
    done[q_array[i]] = True
# print(rets)
if 0 in rets:
    print(-1)
    exit()

for ret in rets:
    if ret > 0:
        print("(", end="")
    else:
        print(")", end="")
print()



from typing import List, Optional, Tuple, Dict, Set
from collections import defaultdict, Counter, deque
import heapq
import math
import bisect
import itertools
import functools


class Solution:
    def smallerNumbersThanCurrent(self, nums: List[int]) -> List[int]:
        count = [0] * 101

    res = []
    for num in nums:
        count[num] += 1
    for num in nums:
        res.append(sum(count[:num]))
    return res



"""
毎回hatのビット列を生成して確かめるっていうのがだめ
境目を動かしていって、境目付近を見ればいい
"""

n = int(input())
s = list(input())
w = list(map(int, input().split()))

people = []
# 正解数
# 最初、0番目の人より左にあって、全て1と予測するので1の数をカウントしておく
cnt = 0
for i in range(n):
    people.append((w[i], s[i]))
    if s[i] == "1":
        cnt += 1
people.sort()

ans = cnt
for i in range(n):  # 左から仕切りをごかす
    w, s = people[i]

    # 0の人を飛び越えたら1足す
    if s == "0":
        cnt += 1
    # 1の人を飛び越えたら1減らす
    if s == "1":
        cnt -= 1

    # 隣の人と体重が同じならそれは境界とはいえない
    # ansの更新を行わない(cntの計算だけしておいてスキップ)
    if i + 1 >= n or w != people[i + 1]:
        ans = max(ans, cnt)

print(ans)



from collections import deque


class Dinic:
    def __init__(self, n):
        self.n = n
        self.links = [[] for _ in range(n)]
        self.depth = None
        self.progress = None

    def add_link(self, _from, to, cap):
        self.links[_from].append([cap, to, len(self.links[to])])
        self.links[to].append([0, _from, len(self.links[_from]) - 1])

    def bfs(self, s):
        depth = [-1] * self.n
        depth[s] = 0
        q = deque([s])
        while q:
            v = q.popleft()
            for cap, to, rev in self.links[v]:
                if cap > 0 and depth[to] < 0:
                    depth[to] = depth[v] + 1
                    q.append(to)
        self.depth = depth

    def dfs(self, v, t, flow):
        if v == t:
            return flow
        links_v = self.links[v]
        for i in range(self.progress[v], len(links_v)):
            self.progress[v] = i
            cap, to, rev = link = links_v[i]
            if cap == 0 or self.depth[v] >= self.depth[to]:
                continue
            d = self.dfs(to, t, min(flow, cap))
            if d == 0:
                continue
            link[0] -= d
            self.links[to][rev][0] += d
            return d
        return 0

    def max_flow(self, s, t):
        flow = 0
        while True:
            self.bfs(s)
            if self.depth[t] < 0:
                return flow
            self.progress = [0] * self.n
            current_flow = self.dfs(s, t, float("inf"))
            while current_flow > 0:
                flow += current_flow
                current_flow = self.dfs(s, t, float("inf"))


N, M = map(int, input().split())
win = [0] * (N + 1)
lose = [0] * (N + 1)
used = {}
for i in range(M):
    a, b = map(int, input().split())
    win[a] += 1
    lose[b] += 1
    if a > b:
        a, b = b, a
    used[a * N + b] = 1
x = max(win)
result = []
count = N * (N - 1) // 2 - M
z = sum(win)
for i in range(1, N + 1):
    rest = N - 1 - win[i] - lose[i]
    y = win[i] + rest
    x = 0
    for j in range(1, N + 1):
        if j == i:
            continue
        x = max(x, win[j])
    if y <= x:
        continue
    r = N**2
    Z = Dinic(r + N + 2)
    e = 0
    for p in range(1, N):
        for q in range(i + 1, N + 1):
            if p == i or q == i:
                continue
            if p * N + q in used:
                continue
            Z.add_link(0, p * N + q, 1)
            e += 1
            Z.add_link(p * N + q, r + p, 1)
            Z.add_link(p * N + q, r + q, 1)
    for p in range(1, N + 1):
        Z.add_link(r + p, r + N + 1, y - 1 - win[p])
    c = Z.max_flow(0, r + N + 1)
    if c == e:
        result.append(i)
print(*result)



R, C = map(int, input().split())

# 行列受け取り
B = []

for i in range(R):
    row = input()
    B.append(row)

# 新しく行列を作成
Q = [["1"] * C for r in range(R)]


for i in range(R):
    for j in range(C):
        # 数値に変換
        # 変換出来たら数値のマンハッタン距離分のマスに"."を入れる
        # 変換できなかった場合は、作成した行列が1の場合のみ、受け取った行列の値を入れる
        b = B[i][j]
        numberCheck = b.isdecimal()
        if numberCheck:
            num = int(b)
            for n in range(-num, num + 1):
                for m in range(-(num - abs(n)), num - abs(n) + 1):
                    if (n + i) >= 0 and (m + j) >= 0 and (n + i) < R and (m + j) < C:
                        Q[n + i][m + j] = "."
        else:
            if Q[i][j] == "1":
                Q[i][j] = "#"

for q in Q:
    for i in q:
        print(i, end="")
    print()



H, W = map(int, input().split())
A = []
for _ in range(H):
    A.append(list(map(int, input().split())))

strings = []
for i in range(H):
    s = ""
    for j in range(W):
        if A[i][j] == 0:
            s += "."
        else:
            s += chr(ord("A") + A[i][j] + 1)
    strings.append(s)

for s in strings:
    print(s)



import asyncio

_counter: int = 0
_lock = asyncio.Lock()


async def increment() -> None:
    global _counter
    val = _counter
    await asyncio.sleep(0)  # yields without holding lock — lost update
    _counter = val + 1


async def run_increments() -> int:
    global _counter, _lock
    _counter = 0
    _lock = asyncio.Lock()
    tasks = [asyncio.create_task(increment()) for _ in range(3)]
    await asyncio.gather(*tasks)
    return _counter


def run() -> int:
    return asyncio.run(run_increments())



import subprocess
import sys


def test_condefects_0():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='1\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '0 0\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_1():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='2\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '332748118 665496236\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_2():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='3\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '174692763 324429416\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_3():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='1000000\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '131664553 564953908\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_4():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='999999\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '112572301 817454957\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )



n, l, r = map(int, input().split())
a = list(map(int, input().split()))

e = []

for i in a:
    now = i
    for j in e:
        now = min(now, now ^ j)
    if now:
        e.append(now)

e.sort(reverse=True)

for i in range(len(e)):
    now = 1 << (e[i].bit_length() - 1)
    for j in range(len(e)):
        if i == j:
            continue
        if e[j] & now:
            e[j] ^= now
    e.sort(reverse=True)

e.sort()


def f(x):
    ans = 0
    for i in range(len(e)):
        if x & 1:
            ans ^= e[i]
        x //= 2
    return ans


print(*[f(i) for i in range(l - 1, r)])
